==> download.php?FileName=terralib-5.3.0.zip: src/terralib/qt/widgets/canvas/ScalePropertyWidget.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

This file is part of the TerraLib - a Framework for building GIS enabled applications.

TerraLib is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

TerraLib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with TerraLib. See COPYING. If not, write to
TerraLib Team at <terralib-team@terralib.org>.
*/

/*!
\file terralib/qt/widgets/canvas/ScalePropertyWidget.cpp
*/

#include "ScalePropertyWidget.h"
#include "ScaleWidget.h"

// TerraLib
#include "../propertybrowser/AbstractPropertyManager.h"

// Qt
#include <QLayout>


te::qt::widgets::ScalePropertyWidget::ScalePropertyWidget(ScaleWidget* wid, QWidget* parent) :
QDockWidget(parent)
{
  QWidget* w = new QWidget(this);

  QtTreePropertyBrowser* pb = new QtTreePropertyBrowser(w);
  pb->setPropertiesWithoutValueMarked(true);
  pb->setResizeMode(QtTreePropertyBrowser::ResizeToContents);

  new ScalePropertyBrowser(pb, wid);

  QGridLayout* lay = new QGridLayout(w);
  lay->addWidget(pb);

  setWidget(w);

  connect(wid, SIGNAL(aboutToBeclosed()), SLOT(scaleWidgetClosed()));
}

te::qt::widgets::ScalePropertyWidget::~ScalePropertyWidget()
{

}

void te::qt::widgets::ScalePropertyWidget::scaleWidgetClosed()
{
  close();
}


te::qt::widgets::ScalePropertyBrowser::ScalePropertyBrowser(QtTreePropertyBrowser* pb, ScaleWidget* wid) :
te::qt::widgets::AbstractPropertyItem(pb)
{
  QMap<int, QIcon> ics;
  QStringList ics_names;
  QStringList units;

  units << tr("Degrees")
    << tr("Kilometers")
    << tr("Meters")
    << tr("Feet");

  GetScalesIcons(ics, ics_names, wid, wid->getRulerColor());

  QtProperty* scale_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Scale properties"));

  QtProperty* header_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Header properties"));
  QtProperty* ruler_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Ruler properties"));
  QtProperty* footer_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Footer properties"));


  // Properties of header
  // ===================
  // Intermediary values visible
  QtProperty* visAll_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->addProperty(tr("Intermediary values visible"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->setValue(visAll_prop, wid->getAllHeaderIsVisible());
  header_prop->addSubProperty(visAll_prop);

  // font
  QtProperty* hfont_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->addProperty(tr("Header font"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->setValue(hfont_prop, wid->getHeaderFont());
  header_prop->addSubProperty(hfont_prop);

  // color
  QtProperty* hcolor_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Header color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(hcolor_prop, wid->getHeaderColor());
  header_prop->addSubProperty(hcolor_prop);
  // ===================

  // Properties of ruler
  // ===================
  // Height in millimeters
  QtProperty* width_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->addProperty(tr("Height in millimeters"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setValue(width_prop, wid->getRulerHeightMM());
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setMinimum(width_prop, 1);
  ruler_prop->addSubProperty(width_prop);

  // Intervals
  QtProperty* intervals_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->addProperty(tr("Number of intervals"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setValue(intervals_prop, wid->getNumberOfIntervals());
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setMinimum(intervals_prop, 1);
  ruler_prop->addSubProperty(intervals_prop);
 
  // Units per gap
  QtProperty* unitsPerGap_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->addProperty(tr("Units per gap"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setValue(unitsPerGap_prop, wid->getUnitsPerGap());
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setMinimum(unitsPerGap_prop, 1);
  ruler_prop->addSubProperty(unitsPerGap_prop);

  // color
  QtProperty* rulerColor_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Ruler color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(rulerColor_prop, wid->getRulerColor());
  ruler_prop->addSubProperty(rulerColor_prop);

  // scale type
  QtProperty* type_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->addProperty(tr("Scale type"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumIcons(type_prop, ics);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumNames(type_prop, ics_names);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setValue(type_prop, wid->getScaleType());
  ruler_prop->addSubProperty(type_prop);
  // ===================

  // Properties of footer
  // ===================
  // numeric scale visible
  QtProperty* num_vis_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->addProperty(tr("Numeric scale visible"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->setValue(num_vis_prop, wid->getNumericScaleIsVisible());
  footer_prop->addSubProperty(num_vis_prop);

  // font
  QtProperty* ffont_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->addProperty(tr("Footer font"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->setValue(ffont_prop, wid->getFooterFont());
  footer_prop->addSubProperty(ffont_prop);

  // color
  QtProperty* fcolor_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Footer color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(fcolor_prop, wid->getFooterColor());
  footer_prop->addSubProperty(fcolor_prop);
  // ===================

  // unit
  QtProperty* unit_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->addProperty(tr("Unit"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumNames(unit_prop, units);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setValue(unit_prop, units.indexOf(wid->getUnit()));
  
  scale_prop->addSubProperty(unit_prop);
  scale_prop->addSubProperty(header_prop);
  scale_prop->addSubProperty(ruler_prop);
  scale_prop->addSubProperty(footer_prop);

  addProperty(scale_prop, tr("Scale"), QColor(175, 255, 175));

  wid->connect(this, SIGNAL(interactHandleChanged(const bool&)), SLOT(setInteractionHandle(const bool&)));

  wid->connect(this, SIGNAL(headerColorChanged(const QColor&)), SLOT(setHeaderColor(const QColor&)));
  wid->connect(this, SIGNAL(rulerColorChanged(const QColor&)), SLOT(setRulerColor(const QColor&)));
  wid->connect(this, SIGNAL(footerColorChanged(const QColor&)), SLOT(setFooterColor(const QColor&)));

  wid->connect(this, SIGNAL(headerFontChanged(const QFont&)), SLOT(setHeaderFont(const QFont&)));
  wid->connect(this, SIGNAL(footerFontChanged(const QFont&)), SLOT(setFooterFont(const QFont&)));

  wid->connect(this, SIGNAL(scaleTypeChanged(const int&)), SLOT(setScaleType(const int&)));
  wid->connect(this, SIGNAL(numericScaleVisibilityChanged(const bool&)), SLOT(setNumericScaleVisble(const bool&)));
  wid->connect(this, SIGNAL(unitChanged(const QString&)), SLOT(setUnit(const QString&)));

  wid->connect(this, SIGNAL(allIntermediaryValuesChanged(const bool&)), SLOT(setAllHeaderVisible(const bool&)));
  wid->connect(this, SIGNAL(rulerHeightChanged(const int&)), SLOT(setRulerHeightMM(const int&)));
  wid->connect(this, SIGNAL(numberOfIntervalsChanged(const int&)), SLOT(setNumberOfIntervals(const int&)));
  wid->connect(this, SIGNAL(unitsPerGapChanged(const int&)), SLOT(setUnitsPerGap(const int&)));
}

te::qt::widgets::ScalePropertyBrowser::~ScalePropertyBrowser()
{
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, bool value)
{
  if (p->propertyName() == tr("Interaction enabled"))
    emit interactHandleChanged(value);
  else if (p->propertyName() == tr("Intermediary values visible"))
    emit allIntermediaryValuesChanged(value);
  else
    emit numericScaleVisibilityChanged(value);
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, const QColor& value)
{
  if (p->propertyName() == tr("Header color"))
    emit headerColorChanged(value);
  else if (p->propertyName() == tr("Ruler color"))
    emit rulerColorChanged(value);
  else
    emit footerColorChanged(value);
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, const QFont& value)
{
  if (p->propertyName() == tr("Header font"))
    emit headerFontChanged(value);
  else
    emit footerFontChanged(value);
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, int value)
{
  if (p->propertyName() == tr("Unit"))
    emit unitChanged(p->valueText());
  else if (p->propertyName() == tr("Height in millimeters"))
    emit rulerHeightChanged(value);
  else if (p->propertyName() == tr("Number of intervals"))
    emit numberOfIntervalsChanged(value);
  else if (p->propertyName() == tr("Units per gap"))
    emit unitsPerGapChanged(value);
  else
    emit scaleTypeChanged(value);
}

==> download.php?FileName=terralib-5.3.2.zip: src/terralib/qt/widgets/canvas/ScalePropertyWidget.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

This file is part of the TerraLib - a Framework for building GIS enabled applications.

TerraLib is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

TerraLib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with TerraLib. See COPYING. If not, write to
TerraLib Team at <terralib-team@terralib.org>.
*/

/*!
\file terralib/qt/widgets/canvas/ScalePropertyWidget.cpp
*/

#include "ScalePropertyWidget.h"
#include "ScaleWidget.h"

// TerraLib
#include "../propertybrowser/AbstractPropertyManager.h"

// Qt
#include <QLayout>


te::qt::widgets::ScalePropertyWidget::ScalePropertyWidget(ScaleWidget* wid, QAction* editScale) :
QDockWidget(0),
m_editAction(editScale),
  m_scaleStatus(true)
{
  QWidget* w = new QWidget(this);

  QtTreePropertyBrowser* pb = new QtTreePropertyBrowser(w);
  pb->setPropertiesWithoutValueMarked(true);
  pb->setResizeMode(QtTreePropertyBrowser::ResizeToContents);

  new ScalePropertyBrowser(pb, wid);

  QGridLayout* lay = new QGridLayout(w);
  lay->addWidget(pb);

  setWidget(w);

  connect(wid, SIGNAL(aboutToBeclosed()), SLOT(scaleWidgetClosed()));

  setAttribute(Qt::WA_DeleteOnClose, true);

  m_editAction->setEnabled(false);
}

te::qt::widgets::ScalePropertyWidget::~ScalePropertyWidget()
{
  m_editAction->setEnabled(m_scaleStatus);
}

void te::qt::widgets::ScalePropertyWidget::scaleWidgetClosed()
{
  m_scaleStatus = false;
  close();
}


te::qt::widgets::ScalePropertyBrowser::ScalePropertyBrowser(QtTreePropertyBrowser* pb, ScaleWidget* wid) :
te::qt::widgets::AbstractPropertyItem(pb)
{
  QMap<int, QIcon> ics;
  QStringList ics_names;
  QStringList units;

  units << tr("Degrees")
    << tr("Kilometers")
    << tr("Meters")
    << tr("Feet");

  GetScalesIcons(ics, ics_names, wid, wid->getRulerColor());

  QtProperty* scale_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Scale properties"));

  QtProperty* header_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Header properties"));
  QtProperty* ruler_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Ruler properties"));
  QtProperty* footer_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Footer properties"));


  // Properties of header
  // ===================
  // Intermediary values visible
  QtProperty* visAll_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->addProperty(tr("Intermediary values visible"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->setValue(visAll_prop, wid->getAllHeaderIsVisible());
  header_prop->addSubProperty(visAll_prop);

  // font
  QtProperty* hfont_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->addProperty(tr("Header font"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->setValue(hfont_prop, wid->getHeaderFont());
  header_prop->addSubProperty(hfont_prop);

  // color
  QtProperty* hcolor_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Header color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(hcolor_prop, wid->getHeaderColor());
  header_prop->addSubProperty(hcolor_prop);
  // ===================

  // Properties of ruler
  // ===================
  // Height in millimeters
  QtProperty* width_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->addProperty(tr("Height in millimeters"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setValue(width_prop, wid->getRulerHeightMM());
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setMinimum(width_prop, 1);
  ruler_prop->addSubProperty(width_prop);

  // Intervals
  QtProperty* intervals_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->addProperty(tr("Number of intervals"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setValue(intervals_prop, wid->getNumberOfIntervals());
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setMinimum(intervals_prop, 1);
  ruler_prop->addSubProperty(intervals_prop);
 
  // Units per gap
  QtProperty* unitsPerGap_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->addProperty(tr("Units per gap"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setValue(unitsPerGap_prop, wid->getUnitsPerGap());
  te::qt::widgets::AbstractPropertyManager::getInstance().m_intManager->setMinimum(unitsPerGap_prop, 1);
  ruler_prop->addSubProperty(unitsPerGap_prop);

  // color
  QtProperty* rulerColor_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Ruler color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(rulerColor_prop, wid->getRulerColor());
  ruler_prop->addSubProperty(rulerColor_prop);

  // scale type
  QtProperty* type_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->addProperty(tr("Scale type"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumIcons(type_prop, ics);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumNames(type_prop, ics_names);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setValue(type_prop, wid->getScaleType());
  ruler_prop->addSubProperty(type_prop);
  // ===================

  // Properties of footer
  // ===================
  // numeric scale visible
  QtProperty* num_vis_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->addProperty(tr("Numeric scale visible"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_boolManager->setValue(num_vis_prop, wid->getNumericScaleIsVisible());
  footer_prop->addSubProperty(num_vis_prop);

  // font
  QtProperty* ffont_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->addProperty(tr("Footer font"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->setValue(ffont_prop, wid->getFooterFont());
  footer_prop->addSubProperty(ffont_prop);

  // color
  QtProperty* fcolor_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Footer color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(fcolor_prop, wid->getFooterColor());
  footer_prop->addSubProperty(fcolor_prop);
  // ===================

  // unit
  QtProperty* unit_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->addProperty(tr("Unit"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumNames(unit_prop, units);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setValue(unit_prop, units.indexOf(wid->getUnit()));
  
  scale_prop->addSubProperty(unit_prop);
  scale_prop->addSubProperty(header_prop);
  scale_prop->addSubProperty(ruler_prop);
  scale_prop->addSubProperty(footer_prop);

  addProperty(scale_prop, tr("Scale"), QColor(175, 255, 175));

  wid->connect(this, SIGNAL(interactHandleChanged(const bool&)), SLOT(setInteractionHandle(const bool&)));

  wid->connect(this, SIGNAL(headerColorChanged(const QColor&)), SLOT(setHeaderColor(const QColor&)));
  wid->connect(this, SIGNAL(rulerColorChanged(const QColor&)), SLOT(setRulerColor(const QColor&)));
  wid->connect(this, SIGNAL(footerColorChanged(const QColor&)), SLOT(setFooterColor(const QColor&)));

  wid->connect(this, SIGNAL(headerFontChanged(const QFont&)), SLOT(setHeaderFont(const QFont&)));
  wid->connect(this, SIGNAL(footerFontChanged(const QFont&)), SLOT(setFooterFont(const QFont&)));

  wid->connect(this, SIGNAL(scaleTypeChanged(const int&)), SLOT(setScaleType(const int&)));
  wid->connect(this, SIGNAL(numericScaleVisibilityChanged(const bool&)), SLOT(setNumericScaleVisble(const bool&)));
  wid->connect(this, SIGNAL(unitChanged(const QString&)), SLOT(setUnit(const QString&)));

  wid->connect(this, SIGNAL(allIntermediaryValuesChanged(const bool&)), SLOT(setAllHeaderVisible(const bool&)));
  wid->connect(this, SIGNAL(rulerHeightChanged(const int&)), SLOT(setRulerHeightMM(const int&)));
  wid->connect(this, SIGNAL(numberOfIntervalsChanged(const int&)), SLOT(setNumberOfIntervals(const int&)));
  wid->connect(this, SIGNAL(unitsPerGapChanged(const int&)), SLOT(setUnitsPerGap(const int&)));
}

te::qt::widgets::ScalePropertyBrowser::~ScalePropertyBrowser()
{
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, bool value)
{
  if (p->propertyName() == tr("Interaction enabled"))
    emit interactHandleChanged(value);
  else if (p->propertyName() == tr("Intermediary values visible"))
    emit allIntermediaryValuesChanged(value);
  else
    emit numericScaleVisibilityChanged(value);
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, const QColor& value)
{
  if (p->propertyName() == tr("Header color"))
    emit headerColorChanged(value);
  else if (p->propertyName() == tr("Ruler color"))
    emit rulerColorChanged(value);
  else
    emit footerColorChanged(value);
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, const QFont& value)
{
  if (p->propertyName() == tr("Header font"))
    emit headerFontChanged(value);
  else
    emit footerFontChanged(value);
}

void te::qt::widgets::ScalePropertyBrowser::valueChanged(QtProperty* p, int value)
{
  if (p->propertyName() == tr("Unit"))
    emit unitChanged(p->valueText());
  else if (p->propertyName() == tr("Height in millimeters"))
    emit rulerHeightChanged(value);
  else if (p->propertyName() == tr("Number of intervals"))
    emit numberOfIntervalsChanged(value);
  else if (p->propertyName() == tr("Units per gap"))
    emit unitsPerGapChanged(value);
  else
    emit scaleTypeChanged(value);
}
